#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-Bf61dX8QasuAQePxnHPc0h
key:                  lsp-2.2.0.0-Bf61dX8QasuAQePxnHPc0h
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  9ee8ee60ab76947cb7fe4d8110721d6d
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-6HLebhUuvFY4cORifnG3Lm:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-6HLebhUuvFY4cORifnG3Lm:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-6HLebhUuvFY4cORifnG3Lm:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-6HLebhUuvFY4cORifnG3Lm:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-Bf61dX8QasuAQePxnHPc0h
depends:
    aeson-2.2.2.0-I4TBg1DJhLsFbcwgkuafNJ
    async-2.2.6-59NIAOAPAyhA1W6qbURVB1
    attoparsec-0.14.4-XKrSjVngnD4c93iEpE5SP base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-GegbEmDZDzC8u9AG844ZWN
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-LnVJu1JSZWR8SeekGz9T3N
    lens-5.3.4-BQIn0OqiEr6M9lJNLT3ya
    lens-aeson-1.2.3-FNGEVG2BAz37NJw8F71qs1
    lsp-types-2.0.2.0-6HLebhUuvFY4cORifnG3Lm mtl-2.3.1
    prettyprinter-1.7.1-1G4msSOkSAQ6gLunBapVuA
    random-1.2.1.3-LwaPdrRXsBLJH2A1U2p1p
    row-types-1.0.1.2-3hIrEFMFAswJoE0cLyHP42
    sorted-list-0.2.3.1-6ZXdAiDBXgq6R083EBOYul stm-2.5.1.0
    temporary-1.3-2gC7gXJ3mT3YNg5WXhcSt text-2.0.2
    text-rope-0.3-JAa6vwbKRJh4B9MtwleuC8 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-9MqMq77Kwyw3AYghIevUCW
    uuid-1.3.16.1-3J3O8qeJuuEHWTlS766m2G

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

